@@ -154,6 +154,8 @@ def get_json():
     if tp not in ('msgpack', 'json'):
         raise ServingError('输入必须是 JSON 或者 MessagePack 格式')
 
+    return payload
+
 
 PREDICT_ARG_HANDLERS = {
     'data': lambda: request.data,
@@ -167,12 +169,25 @@ PREDICT_ARG_HANDLERS = {
 predict_blueprint = Blueprint('openbayes-serv-predict', __name__)
 
 
-@predict_blueprint.route('/', methods=['GET'])
+CORS_HEADERS = {
+    'Access-Control-Allow-Origin': '*',
+    'Access-Control-Allow-Methods': 'GET,POST,PUT,DELETE,OPTIONS',
+    'Access-Control-Allow-Credentials': 'true',
+    'Access-Control-Max-Age': '86400',
+}
+
+
+@predict_blueprint.route('/', methods=['GET'], provide_automatic_options=False)
 def help_message():
-    return {'message': 'Serving 服务正常工作，可以发送 POST 请求到此地址进行推理。'}
+    return {'message': 'Serving 服务正常工作，可以发送 POST 请求到此地址进行推理。'}, 200, CORS_HEADERS
 
 
-@predict_blueprint.route('/', methods=['POST'])
+@predict_blueprint.route('/', methods=['OPTIONS'], provide_automatic_options=False)
+def request_options():
+    return b'', 200, CORS_HEADERS
+
+
+@predict_blueprint.route('/', methods=['POST'], provide_automatic_options=False)
 def model_predict():
     try:
         obj = current_app.config['OPENBAYES_SERVING_PREDICTOR_OBJECT']
@@ -181,22 +196,25 @@ def model_predict():
         # TODO: Parse Accept and optionally send msgpack payload
         rst = obj.predict(**kwargs)
         if isinstance(rst, (dict, list, tuple)):
-            return jsonify(rst)
+            resp = jsonify(rst)
+            resp.headers.extend(CORS_HEADERS)
+            return resp
         elif isinstance(rst, bytes):
             mimetype = 'application/octet-stream'
             if rst.startswith(b'\x89PNG'):
                 mimetype = 'image/png'
             elif rst.startswith(b'\xff\xd8') and rst.endswith(b'\xff\xd9'):
                 mimetype = 'image/jpeg'
-            return Response(rst, mimetype=mimetype)
+            return Response(rst, mimetype=mimetype, headers=CORS_HEADERS)
         elif callable(rst):
             return rst
         else:
             log.error('predict 函数返回了无效的结果：%s', rst)
             log.debug('有效的结果有 dict、list、tuple 对象，会被编码成 JSON；bytes、str 对象，会直接返回给客户端。')
-            return {}, 500
+            return {}, 500, CORS_HEADERS
     except ServingError as e:
         response = jsonify(e.payload)
+        response.headers.extend(CORS_HEADERS)
         response.status_code = e.status_code
         return response
     except HTTPException:
@@ -207,9 +225,9 @@ def model_predict():
         if state:
             rv = state.collect()
             log.error(f'使用浏览器打开 {rv["url"]} 调试此次失败的请求')
-            return {'debug_url': rv['url']}, 500
+            return {'debug_url': rv['url']}, 500, CORS_HEADERS
 
-        return {}, 500
+        return {}, 500, CORS_HEADERS
 
 
 @predict_blueprint.app_errorhandler(400)
